@@ -7,7 +7,7 @@ public class LocalMultiple {
   public void foo(Object o) {
     List myList = null;
 
-    if (myList.size() != 0) {
+    if (myList.size() != 0) { // equivalent to !myList.isEmpty()
       /* @UnderInitialization*/ Set localVar = null;
       myList.add(localVar);
     } else {
