@@ -25,7 +25,14 @@ if grep -n -r --exclude-dir=build --exclude-dir=examples --exclude-dir=jtreg --e
   echo "Don't use static import or wildcard import"
   exit 1
 fi
-make style-check --jobs="$(getconf _NPROCESSORS_ONLN)"
+
+# Under CI, there are two CPUs, but limit to 1 to avoid out-of-memory error.
+if [ -n "$("$CHECKERFRAMEWORK"/checker/bin-devel/is-ci.sh)" ]; then
+  num_jobs=1
+else
+  num_jobs="$(nproc || sysctl -n hw.ncpu || getconf _NPROCESSORS_ONLN || echo 1)"
+fi
+make style-check --jobs="${num_jobs}"
 
 ## HTML legality
 ./gradlew htmlValidate --warning-mode=all
