@@ -1,7 +1,6 @@
 package org.checkerframework.checker.index.samelen;
 
 import org.checkerframework.common.basetype.BaseTypeChecker;
-import org.checkerframework.framework.qual.RelevantJavaTypes;
 import org.checkerframework.framework.source.SuppressWarningsPrefix;
 
 /**
@@ -10,6 +9,11 @@ import org.checkerframework.framework.source.SuppressWarningsPrefix;
  *
  * @checker_framework.manual #index-checker Index Checker
  */
-@RelevantJavaTypes({CharSequence.class, Object[].class})
+// This @RelevantJavaTypes annotation is incorrect, because @SameLen can apply to an arbitrary
+// user-defined datatype: https://checkerframework.org/manual/#index-annotating-fixed-size .
+// @RelevantJavaTypes({CharSequence.class, Object[].class, Object.class})
 @SuppressWarningsPrefix({"index", "samelen"})
-public class SameLenChecker extends BaseTypeChecker {}
+public class SameLenChecker extends BaseTypeChecker {
+  /** Create a new SameLenChecker. */
+  public SameLenChecker() {}
+}
