@@ -1,11 +1,11 @@
 package org.checkerframework.checker.nullness;
 
-import java.util.Set;
-import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.type.TypeMirror;
+import org.checkerframework.checker.nullness.qual.Nullable;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.framework.flow.CFAbstractAnalysis;
 import org.checkerframework.framework.flow.CFAbstractValue;
+import org.checkerframework.javacutil.AnnotationMirrorSet;
 
 /**
  * The analysis class for the non-null type system (serves as factory for the transfer function,
@@ -35,9 +35,9 @@ public class NullnessAnalysis
   }
 
   @Override
-  public NullnessValue createAbstractValue(
-      Set<AnnotationMirror> annotations, TypeMirror underlyingType) {
-    if (!CFAbstractValue.validateSet(annotations, underlyingType, qualifierHierarchy)) {
+  public @Nullable NullnessValue createAbstractValue(
+      AnnotationMirrorSet annotations, TypeMirror underlyingType) {
+    if (!CFAbstractValue.validateSet(annotations, underlyingType, atypeFactory)) {
       return null;
     }
     return new NullnessValue(this, annotations, underlyingType);
