@@ -505,7 +505,7 @@ public class OptionalImplVisitor
     ExpressionTree method = invok.getMethodSelect();
 
     String methodString = method.toString();
-    int dotPos = methodString.lastIndexOf(".");
+    int dotPos = methodString.lastIndexOf('.');
     if (dotPos != -1) {
       methodString = methodString.substring(0, dotPos) + "::" + methodString.substring(dotPos + 1);
     }
@@ -637,7 +637,7 @@ public class OptionalImplVisitor
    * <p>If an Optional value is compared with the null literal, it indicates that the programmer
    * expects it might have been assigned a null value (or no value at all) somewhere in the code.
    *
-   * @param tree a binary tree representing a binary operation.
+   * @param tree a binary tree representing a binary operation
    */
   private void handleCompareToNull(BinaryTree tree) {
     if (!isEqualityOperation(tree)) {
@@ -879,7 +879,7 @@ public class OptionalImplVisitor
   }
 
   /**
-   * Return true if tm is a subtype of Collection (other than the Null type).
+   * Returns true if tm is a subtype of Collection (other than the Null type).
    *
    * @param tm a type
    * @return true if the given type is a subtype of Collection
@@ -898,7 +898,8 @@ public class OptionalImplVisitor
               "java.util.OptionalLong"));
 
   /**
-   * Return true if tm is class Optional, OptionalDouble, OptionalInt, or OptionalLong in java.util.
+   * Returns true if tm is class Optional, OptionalDouble, OptionalInt, or OptionalLong in
+   * java.util.
    *
    * @param tm a type
    * @return true if the given type is Optional, OptionalDouble, OptionalInt, or OptionalLong
