@@ -26,7 +26,7 @@ import org.checkerframework.framework.type.treeannotator.ListTreeAnnotator;
 import org.checkerframework.framework.type.treeannotator.TreeAnnotator;
 import org.checkerframework.javacutil.AnnotationBuilder;
 import org.plumelib.reflection.Signatures;
-import org.plumelib.util.CollectionsPlume;
+import org.plumelib.util.MapsP;
 
 /**
  * This AnnotatedTypeFactory adds PropertyKey annotations to String literals that contain values
@@ -36,6 +36,7 @@ public class PropertyKeyAnnotatedTypeFactory extends BaseAnnotatedTypeFactory {
 
   private final Set<String> lookupKeys;
 
+  @SuppressWarnings("this-escape")
   public PropertyKeyAnnotatedTypeFactory(BaseTypeChecker checker) {
     super(checker);
     this.lookupKeys = Collections.unmodifiableSet(buildLookupKeys());
@@ -154,7 +155,7 @@ public class PropertyKeyAnnotatedTypeFactory extends BaseAnnotatedTypeFactory {
       return Collections.emptySet();
     }
 
-    Set<String> result = new HashSet<>(CollectionsPlume.mapCapacity(propfiles));
+    Set<String> result = new HashSet<>(MapsP.mapCapacity(propfiles));
 
     for (String propfile : propfiles) {
       try {
@@ -211,7 +212,7 @@ public class PropertyKeyAnnotatedTypeFactory extends BaseAnnotatedTypeFactory {
       return Collections.emptySet();
     }
 
-    Set<String> result = new HashSet<>(CollectionsPlume.mapCapacity(bundleNames));
+    Set<String> result = new HashSet<>(MapsP.mapCapacity(bundleNames));
 
     for (String bundleName : bundleNames) {
       if (!Signatures.isBinaryName(bundleName)) {
