@@ -2,6 +2,8 @@ package org.checkerframework.checker.rlccalledmethods;
 
 import com.google.common.collect.BiMap;
 import com.google.common.collect.HashBiMap;
+import com.sun.source.tree.ClassTree;
+import com.sun.source.tree.LambdaExpressionTree;
 import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.NewClassTree;
@@ -11,6 +13,7 @@ import java.lang.annotation.Annotation;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
+import java.util.Queue;
 import java.util.Set;
 import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.element.Element;
@@ -47,6 +50,7 @@ import org.checkerframework.dataflow.cfg.block.Block;
 import org.checkerframework.dataflow.cfg.node.LocalVariableNode;
 import org.checkerframework.dataflow.cfg.node.MethodInvocationNode;
 import org.checkerframework.dataflow.cfg.node.Node;
+import org.checkerframework.framework.flow.CFAbstractAnalysis.FieldInitialValue;
 import org.checkerframework.framework.flow.CFStore;
 import org.checkerframework.framework.source.SourceChecker;
 import org.checkerframework.framework.type.AnnotatedTypeMirror;
@@ -56,6 +60,7 @@ import org.checkerframework.javacutil.AnnotationUtils;
 import org.checkerframework.javacutil.ElementUtils;
 import org.checkerframework.javacutil.TreeUtils;
 import org.checkerframework.javacutil.TypeSystemError;
+import org.plumelib.util.IPair;
 
 /**
  * The type factory for the RLCCalledMethodsChecker. The main difference between this and the Called
@@ -143,7 +148,39 @@ public class RLCCalledMethodsAnnotatedTypeFactory extends CalledMethodsAnnotated
   }
 
   @Override
-  public void postAnalyze(ControlFlowGraph cfg) {
+  protected ControlFlowGraph analyze(
+      Queue<IPair<ClassTree, @Nullable AccumulationStore>> classQueue,
+      Queue<IPair<LambdaExpressionTree, @Nullable AccumulationStore>> lambdaQueue,
+      UnderlyingAST ast,
+      List<FieldInitialValue<AccumulationValue>> fieldValues,
+      @Nullable ControlFlowGraph cfg,
+      boolean isInitializationCode,
+      boolean updateInitializationStore,
+      boolean isStatic,
+      @Nullable AccumulationStore capturedStore) {
+    // This is a workaround for a bug that I tried and failed to fix.
+    // See checker/tests/resourceleak/RLLambda.java.
+    // This code really belongs in postAnalyze, but this code only works correctly when called after
+    // a method is analyzed the first time and before any containing lambdas are analyzed.
+    // This workaround means there could be false positives when the type of a method invocation
+    // depends on dataflow in a lambda.
+
+    if (cfg != null) {
+      // The cfg is not null, so the analysis has been run before.  Don't rerun it.
+      return cfg;
+    }
+    cfg =
+        super.analyze(
+            classQueue,
+            lambdaQueue,
+            ast,
+            fieldValues,
+            cfg,
+            isInitializationCode,
+            updateInitializationStore,
+            isStatic,
+            capturedStore);
+    assert root != null : "@AssumeAssertion(nullness): at this point root is always nonnull";
     rlc.setRoot(root);
     MustCallConsistencyAnalyzer mustCallConsistencyAnalyzer = new MustCallConsistencyAnalyzer(rlc);
     mustCallConsistencyAnalyzer.analyze(cfg);
@@ -156,8 +193,8 @@ public class RLCCalledMethodsAnnotatedTypeFactory extends CalledMethodsAnnotated
       }
     }
 
-    super.postAnalyze(cfg);
     tempVarToTree.clear();
+    return cfg;
   }
 
   @Override
