@@ -11,13 +11,14 @@ import org.junit.runners.Parameterized.Parameters;
  */
 public class NullnessPermitClearPropertyTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public NullnessPermitClearPropertyTest(List<File> testFiles) {
     super(
         testFiles,
         org.checkerframework.checker.nullness.NullnessChecker.class,
         "nullness",
-        "-Anomsgtext",
         "-Alint=permitClearProperty");
   }
 
