@@ -18,8 +18,7 @@ public class NullnessReflectionTest extends CheckerFrameworkPerDirectoryTest {
         testFiles,
         org.checkerframework.checker.nullness.NullnessChecker.class,
         "nullness",
-        "-AresolveReflection",
-        "-Anomsgtext");
+        "-AresolveReflection");
   }
 
   @Parameters
