@@ -1,13 +1,13 @@
-import org.checkerframework.checker.testchecker.ainfer.qual.Sibling2;
+import org.checkerframework.checker.testchecker.ainfer.qual.AinferSibling2;
 
 abstract class MethodOverrideInSubtype2 extends MethodDefinedInSupertype {
 
-  private @Sibling2 int getSibling2() {
+  private @AinferSibling2 int getAinferSibling2() {
     return 0;
   }
 
   @java.lang.Override
   public int shouldReturnParent() {
-    return getSibling2();
+    return getAinferSibling2();
   }
 }
