@@ -6,6 +6,6 @@ abstract class EditLogInputStream implements Closeable {
 }
 
 interface JournalSet extends Closeable {
-  static final Comparator<EditLogInputStream> LOCAL_LOG_PREFERENCE_COMPARATOR =
+  static final Comparator<? extends EditLogInputStream> LOCAL_LOG_PREFERENCE_COMPARATOR =
       Comparator.comparing(EditLogInputStream::isLocalLog).reversed();
 }
