@@ -1,13 +1,13 @@
 import org.checkerframework.checker.calledmethods.qual.*;
 import org.checkerframework.checker.mustcall.qual.*;
-import org.checkerframework.common.returnsreceiver.qual.*;
 
 class ACMethodInvocationTest {
 
-  @MustCall("a") class Foo {
+  @InheritableMustCall("a")
+  class Foo {
     void a() {}
 
-    @This Foo b() {
+    Foo b() {
       return this;
     }
 
@@ -25,28 +25,17 @@ class ACMethodInvocationTest {
     return f;
   }
 
-  @Owning
-  @CalledMethods({"b"}) Foo makeFooFinalize2() {
-    Foo f = new Foo();
-    f.b();
-    return f;
-  }
-
   void CallMethodsInSequence() {
     makeFoo().a();
   }
 
-  void CallMethodsInSequence2() {
-    makeFoo().b().a();
-  }
-
   void testFluentAPIWrong() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     makeFoo().b();
   }
 
   void testFluentAPIWrong2() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     makeFoo();
   }
 
@@ -54,13 +43,8 @@ class ACMethodInvocationTest {
     makeFooFinalize();
   }
 
-  void invokeMethodWithCallBWrong() {
-    // :: error: required.method.not.called
-    makeFooFinalize2();
-  }
-
   void invokeMethodAndCallCWrong() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     makeFoo().c();
   }
 
@@ -73,9 +57,9 @@ class ACMethodInvocationTest {
   Foo testField3;
 
   void testStoringInField() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     testField1 = makeFoo();
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     testField2 = new Foo();
 
     testField3 = makeFooFinalize();
