@@ -8,10 +8,11 @@ import org.checkerframework.common.returnsreceiver.qual.*;
 class ManualMustCallEmptyOnConstructor {
 
   // Test that writing @MustCall({}) on a constructor results in an error
-  @MustCall("a") static class Foo {
+  @InheritableMustCall("a")
+  static class Foo {
     final @Owning InputStream is;
 
-    // :: error: inconsistent.constructor.type
+    // :: error: (inconsistent.constructor.type)
     @MustCall({}) Foo(@Owning InputStream is) {
       this.is = is;
     }
