@@ -21,8 +21,15 @@ public class ImplicitThisNode extends ThisNode {
     return visitor.visitImplicitThis(this, p);
   }
 
+  // In an inner class context, an implicit this may need to be represented as "Outer.this" rather
+  // than just as "this".  This is context-dependent, and toString doesn't know if it is being
+  // used in an inner class context.
   @Override
   public String toString() {
-    return "(" + getName() + ")";
+    if (Node.disambiguateOwner) {
+      return "(this{owner=" + type + "})";
+    } else {
+      return "(this)";
+    }
   }
 }
