@@ -83,7 +83,7 @@ public class AccumulationTransfer
     }
 
     Tree tree = node.getTree();
-    if (tree != null && tree.getKind() == Tree.Kind.METHOD_INVOCATION) {
+    if (tree != null && tree instanceof MethodInvocationTree) {
       Node receiver = ((MethodInvocationNode) node).getTarget().getReceiver();
       if (receiver != null && atypeFactory.returnsThis((MethodInvocationTree) tree)) {
         accumulate(receiver, result, values);
