@@ -6,7 +6,7 @@ import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.common.basetype.BaseTypeVisitor;
 import org.checkerframework.common.value.ValueChecker;
 import org.checkerframework.framework.source.SourceChecker;
-import org.plumelib.util.CollectionsPlume;
+import org.plumelib.util.MapsP;
 
 /**
  * The MethodVal Checker provides a sound estimate of the signature of Method objects.
@@ -23,8 +23,7 @@ public class MethodValChecker extends BaseTypeChecker {
   protected Set<Class<? extends SourceChecker>> getImmediateSubcheckerClasses() {
     // Don't call super otherwise MethodVal will be added as a subChecker
     // which creates a circular dependency.
-    Set<Class<? extends SourceChecker>> subCheckers =
-        new LinkedHashSet<>(CollectionsPlume.mapCapacity(2));
+    Set<Class<? extends SourceChecker>> subCheckers = new LinkedHashSet<>(MapsP.mapCapacity(2));
     subCheckers.add(ValueChecker.class);
     subCheckers.add(ClassValChecker.class);
     return subCheckers;
