@@ -97,6 +97,7 @@ import org.plumelib.util.ArraySet;
 import org.plumelib.util.CollectionsPlume;
 import org.plumelib.util.DeepCopyable;
 import org.plumelib.util.IPair;
+import org.plumelib.util.MapsP;
 import org.plumelib.util.UtilPlume;
 
 /**
@@ -143,7 +144,7 @@ public class WholeProgramInferenceJavaParserStorage
   /** Maps from binary class name to the source file that contains it. */
   private Map<String, String> classToSource = new HashMap<>();
 
-  /** Whether the {@code -AinferOutputOriginal} option was supplied to the checker. */
+  /** True if the {@code -AinferOutputOriginal} option was supplied to the checker. */
   private final boolean inferOutputOriginal;
 
   /**
@@ -177,7 +178,7 @@ public class WholeProgramInferenceJavaParserStorage
    * annotations.
    *
    * @param atypeFactory the associated type factory
-   * @param inferOutputOriginal whether the -AinferOutputOriginal option was supplied to the checker
+   * @param inferOutputOriginal true if the -AinferOutputOriginal option was supplied to the checker
    */
   public WholeProgramInferenceJavaParserStorage(
       AnnotatedTypeFactory atypeFactory, boolean inferOutputOriginal) {
@@ -271,7 +272,7 @@ public class WholeProgramInferenceJavaParserStorage
   }
 
   /**
-   * Get the annotations for a method or constructor.
+   * Returns the annotations for a method or constructor.
    *
    * @param methodElt the method or constructor
    * @return the annotations for a method or constructor
@@ -290,7 +291,7 @@ public class WholeProgramInferenceJavaParserStorage
   }
 
   /**
-   * Get the annotations for a field.
+   * Returns the annotations for a field.
    *
    * @param fieldElt a field
    * @return the annotations for a field
@@ -979,7 +980,7 @@ public class WholeProgramInferenceJavaParserStorage
   }
 
   /**
-   * Return all the CallableDeclarationAnnos for the given signature.
+   * Returns all the CallableDeclarationAnnos for the given signature.
    *
    * @param jvmSignature the JVM signature
    * @param typeNames a collection of type names
@@ -1393,8 +1394,8 @@ public class WholeProgramInferenceJavaParserStorage
     @Override
     public ClassOrInterfaceAnnos deepCopy() {
       ClassOrInterfaceAnnos result = new ClassOrInterfaceAnnos(className, classDeclaration);
-      result.callableDeclarations = CollectionsPlume.deepCopyValues(callableDeclarations);
-      result.fields = CollectionsPlume.deepCopyValues(fields);
+      result.callableDeclarations = MapsP.deepCopyValues(callableDeclarations);
+      result.fields = MapsP.deepCopyValues(fields);
       result.enumConstants = UtilPlume.clone(enumConstants); // no deep copy: elements are strings
       if (classAnnotations != null) {
         result.classAnnotations = classAnnotations.deepCopy();
@@ -1918,7 +1919,7 @@ public class WholeProgramInferenceJavaParserStorage
     if (orig == null) {
       return null;
     }
-    Map<String, InferredDeclared> result = new HashMap<>(CollectionsPlume.mapCapacity(orig.size()));
+    Map<String, InferredDeclared> result = new HashMap<>(MapsP.mapCapacity(orig.size()));
     result.clear();
     for (Map.Entry<String, InferredDeclared> entry : orig.entrySet()) {
       String javaExpression = entry.getKey();
