@@ -216,8 +216,16 @@ public abstract class CFAbstractAnalysis<
   public abstract @Nullable V createAbstractValue(
       AnnotationMirrorSet annotations, TypeMirror underlyingType);
 
-  /** Default implementation for {@link #createAbstractValue(AnnotationMirrorSet, TypeMirror)}. */
-  public @Nullable CFValue defaultCreateAbstractValue(
+  // This cannot be inlined into `createAbstractValue()`, because the Java type system forbids it.
+  /**
+   * Default implementation for {@link #createAbstractValue(AnnotationMirrorSet, TypeMirror)}.
+   *
+   * @param analysis the analysis
+   * @param annotations the annotations for the result annotated type
+   * @param underlyingType the unannotated type for the result annotated type
+   * @return an abstract value containing the given {@code annotations} and {@code underlyingType}
+   */
+  public final @Nullable CFValue getCfValue(
       CFAbstractAnalysis<CFValue, ?, ?> analysis,
       AnnotationMirrorSet annotations,
       TypeMirror underlyingType) {
@@ -227,6 +235,11 @@ public abstract class CFAbstractAnalysis<
     return new CFValue(analysis, annotations, underlyingType);
   }
 
+  /**
+   * Returns the type hierarchy.
+   *
+   * @return the type hierarchy
+   */
   public TypeHierarchy getTypeHierarchy() {
     return typeHierarchy;
   }
