@@ -1,6 +1,7 @@
 package org.checkerframework.framework.flow;
 
 import javax.lang.model.type.TypeMirror;
+import org.checkerframework.checker.nullness.qual.Nullable;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.framework.type.GenericAnnotatedTypeFactory;
 import org.checkerframework.javacutil.AnnotationMirrorSet;
@@ -31,7 +32,8 @@ public class CFAnalysis extends CFAbstractAnalysis<CFValue, CFStore, CFTransfer>
   }
 
   @Override
-  public CFValue createAbstractValue(AnnotationMirrorSet annotations, TypeMirror underlyingType) {
-    return defaultCreateAbstractValue(this, annotations, underlyingType);
+  public @Nullable CFValue createAbstractValue(
+      AnnotationMirrorSet annotations, TypeMirror underlyingType) {
+    return getCfValue(this, annotations, underlyingType);
   }
 }
