@@ -84,9 +84,9 @@ public final class TypesIntoElements {
     */
 
     for (Tree mem : tree.getMembers()) {
-      if (mem.getKind() == Tree.Kind.METHOD) {
+      if (mem instanceof MethodTree) {
         storeMethod(processingEnv, types, atypeFactory, (MethodTree) mem);
-      } else if (mem.getKind() == Tree.Kind.VARIABLE) {
+      } else if (mem instanceof VariableTree) {
         storeVariable(processingEnv, types, atypeFactory, (VariableTree) mem);
       } else {
         // System.out.println("Unhandled member tree: " + mem);
@@ -387,8 +387,13 @@ public final class TypesIntoElements {
       return res;
     }
 
-    /* Modeled after
-     * {@link com.sun.tools.javac.code.TypeAnnotations.TypeAnnotationPositions#locateNestedTypes(Type, TypeAnnotationPosition)}
+    /**
+     * Modeled after {@code
+     * com.sun.tools.javac.code.TypeAnnotations.TypeAnnotationPositions#locateNestedTypes(Type,
+     * TypeAnnotationPosition)}.
+     *
+     * @param type a type
+     * @param p the type's position
      */
     private void locateNestedTypes(AnnotatedDeclaredType type, TypeAnnotationPosition p) {
       // The number of "steps" to get from the full type to the
