@@ -20,6 +20,7 @@ import org.checkerframework.framework.type.AnnotatedTypeMirror.AnnotatedUnionTyp
 import org.checkerframework.framework.type.AnnotatedTypeMirror.AnnotatedWildcardType;
 import org.checkerframework.framework.type.QualifierHierarchy;
 import org.checkerframework.framework.type.visitor.AbstractAtmComboVisitor;
+import org.checkerframework.javacutil.AnnotationMirrorSet;
 import org.checkerframework.javacutil.BugInCF;
 import org.checkerframework.javacutil.TypesUtils;
 
@@ -31,8 +32,12 @@ import org.checkerframework.javacutil.TypesUtils;
  */
 class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
 
+  /** The type factory. */
   private final AnnotatedTypeFactory atypeFactory;
-  private final QualifierHierarchy qualifierHierarchy;
+
+  /** The qualifier hierarchy. */
+  private final QualifierHierarchy qualHierarchy;
+
   /**
    * List of {@link AnnotatedTypeVariable} or {@link AnnotatedWildcardType} that have been visited.
    * Call {@link #visited(AnnotatedTypeMirror)} to check if the type have been visited, so that
@@ -42,7 +47,7 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
 
   AtmLubVisitor(AnnotatedTypeFactory atypeFactory) {
     this.atypeFactory = atypeFactory;
-    this.qualifierHierarchy = atypeFactory.getQualifierHierarchy();
+    this.qualHierarchy = atypeFactory.getQualifierHierarchy();
   }
 
   /**
@@ -69,21 +74,32 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
     return lub;
   }
 
+  /**
+   * Lub a type with the nulltype.
+   *
+   * @param nullType an annotated null type
+   * @param otherType the other type to lub
+   * @param lub a type mirror that will be copied, side-effected, and returned
+   * @return the lub
+   */
   private AnnotatedTypeMirror lubWithNull(
       AnnotatedNullType nullType, AnnotatedTypeMirror otherType, AnnotatedTypeMirror lub) {
+    TypeMirror nullTM = nullType.getUnderlyingType();
     AnnotatedTypeMirror otherAsLub;
     if (otherType.getKind() == TypeKind.NULL) {
       otherAsLub = otherType.deepCopy();
     } else {
       otherAsLub = AnnotatedTypes.asSuper(atypeFactory, otherType, lub);
     }
+    TypeMirror otherTM = otherAsLub.getUnderlyingType();
 
     lub = otherAsLub.deepCopy();
 
     if (otherAsLub.getKind() != TypeKind.TYPEVAR && otherAsLub.getKind() != TypeKind.WILDCARD) {
-      for (AnnotationMirror nullAnno : nullType.getAnnotations()) {
-        AnnotationMirror otherAnno = otherAsLub.getAnnotationInHierarchy(nullAnno);
-        AnnotationMirror lubAnno = qualifierHierarchy.leastUpperBound(nullAnno, otherAnno);
+      for (AnnotationMirror nullAnno : nullType.getPrimaryAnnotations()) {
+        AnnotationMirror otherAnno = otherAsLub.getPrimaryAnnotationInHierarchy(nullAnno);
+        AnnotationMirror lubAnno =
+            qualHierarchy.leastUpperBoundShallow(nullAnno, nullTM, otherAnno, otherTM);
         lub.replaceAnnotation(lubAnno);
       }
       return lub;
@@ -93,16 +109,16 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
     // if @L <: @U <: @N then LUB(@N null, T) = @N T
     // if @L <: @N <:@U && @N != @L  then LUB(@N null, T) = @U T
     // if @N <: @L <: @U             then LUB(@N null, T) =    T
-    Set<AnnotationMirror> lowerBounds =
-        AnnotatedTypes.findEffectiveLowerBoundAnnotations(qualifierHierarchy, otherAsLub);
+    AnnotationMirrorSet lowerBounds =
+        AnnotatedTypes.findEffectiveLowerBoundAnnotations(qualHierarchy, otherAsLub);
     for (AnnotationMirror lowerBound : lowerBounds) {
-      AnnotationMirror nullAnno = nullType.getAnnotationInHierarchy(lowerBound);
+      AnnotationMirror nullAnno = nullType.getPrimaryAnnotationInHierarchy(lowerBound);
       AnnotationMirror upperBound = otherAsLub.getEffectiveAnnotationInHierarchy(lowerBound);
-      if (qualifierHierarchy.isSubtype(upperBound, nullAnno)) {
+      if (qualHierarchy.isSubtypeShallow(upperBound, otherTM, nullAnno, nullTM)) {
         // @L <: @U <: @N
         lub.replaceAnnotation(nullAnno);
-      } else if (qualifierHierarchy.isSubtype(lowerBound, nullAnno)
-          && !qualifierHierarchy.isSubtype(nullAnno, lowerBound)) {
+      } else if (qualHierarchy.isSubtypeShallow(lowerBound, otherTM, nullAnno, nullTM)
+          && !qualHierarchy.isSubtypeShallow(nullAnno, nullTM, lowerBound, otherTM)) {
         // @L <: @N <:@U && @N != @L
         lub.replaceAnnotation(upperBound);
       } // else @N <: @L <: @U
@@ -117,17 +133,29 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
   private void lubPrimaryAnnotations(
       AnnotatedTypeMirror type1, AnnotatedTypeMirror type2, AnnotatedTypeMirror lub) {
     Set<? extends AnnotationMirror> lubSet;
-    if (type1.getAnnotations().isEmpty()) {
-      lubSet = type2.getAnnotations();
-    } else if (type2.getAnnotations().isEmpty()) {
-      lubSet = type1.getAnnotations();
+    if (type1.getPrimaryAnnotations().isEmpty()) {
+      lubSet = type2.getPrimaryAnnotations();
+    } else if (type2.getPrimaryAnnotations().isEmpty()) {
+      lubSet = type1.getPrimaryAnnotations();
     } else {
-      lubSet = qualifierHierarchy.leastUpperBounds(type1.getAnnotations(), type2.getAnnotations());
+      lubSet =
+          qualHierarchy.leastUpperBoundsShallow(
+              type1.getPrimaryAnnotations(),
+              type2.getUnderlyingType(),
+              type2.getPrimaryAnnotations(),
+              type2.getUnderlyingType());
     }
     lub.replaceAnnotations(lubSet);
   }
 
-  /** Casts lub to the type of type and issues an error if type and lub are not the same kind. */
+  /**
+   * Casts lub to the type of type, or issues an error if type and lub are not the same kind.
+   *
+   * @param <T> the type to cast to
+   * @param type a values of the type to cast to
+   * @param lub the value to cast to {@code T}
+   * @return {@code lub}, casted to {@code T}
+   */
   private <T extends AnnotatedTypeMirror> T castLub(T type, AnnotatedTypeMirror lub) {
     if (type.getKind() != lub.getKind()) {
       throw new BugInCF(
@@ -185,9 +213,10 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
   private void lubTypeArgument(
       AnnotatedTypeMirror type1, AnnotatedTypeMirror type2, AnnotatedTypeMirror lub) {
     // In lub(), asSuper is called on type1 and type2, but asSuper does not recur into type
-    // arguments, so call asSuper on the type arguments so that they have the same underlying type.
-    final AnnotatedTypeMirror type1AsLub = AnnotatedTypes.asSuper(atypeFactory, type1, lub);
-    final AnnotatedTypeMirror type2AsLub = AnnotatedTypes.asSuper(atypeFactory, type2, lub);
+    // arguments, so call asSuper on the type arguments so that they have the same underlying
+    // type.
+    AnnotatedTypeMirror type1AsLub = AnnotatedTypes.asSuper(atypeFactory, type1, lub);
+    AnnotatedTypeMirror type2AsLub = AnnotatedTypes.asSuper(atypeFactory, type2, lub);
 
     // If the type argument is a wildcard or captured type argument, then the lub computation is
     // slightly different.  The primary annotation on the lower bound is the glb of lower bounds
@@ -203,8 +232,8 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
       AnnotatedWildcardType type1Wildcard = (AnnotatedWildcardType) type1AsLub;
       AnnotatedWildcardType type2Wildcard = (AnnotatedWildcardType) type2AsLub;
       AnnotatedWildcardType lubWildcard = (AnnotatedWildcardType) lub;
-      if (type1Wildcard.isUninferredTypeArgument() || type2Wildcard.isUninferredTypeArgument()) {
-        lubWildcard.setUninferredTypeArgument();
+      if (type1Wildcard.isTypeArgOfRawType() || type2Wildcard.isTypeArgOfRawType()) {
+        lubWildcard.setTypeArgOfRawType();
       }
       lubWildcard(
           type1Wildcard.getSuperBound(),
@@ -245,12 +274,14 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
     visit(type1UpperBound, type2UpperBound, lubUpperBound);
     visit(type1LowerBound, type2LowerBound, lubLowerBound);
 
-    for (AnnotationMirror top : qualifierHierarchy.getTopAnnotations()) {
-      AnnotationMirror anno1 = type1LowerBound.getAnnotationInHierarchy(top);
-      AnnotationMirror anno2 = type2LowerBound.getAnnotationInHierarchy(top);
+    TypeMirror tm1 = type1LowerBound.getUnderlyingType();
+    TypeMirror tm2 = type2LowerBound.getUnderlyingType();
+    for (AnnotationMirror top : qualHierarchy.getTopAnnotations()) {
+      AnnotationMirror anno1 = type1LowerBound.getPrimaryAnnotationInHierarchy(top);
+      AnnotationMirror anno2 = type2LowerBound.getPrimaryAnnotationInHierarchy(top);
 
       if (anno1 != null && anno2 != null) {
-        AnnotationMirror glb = qualifierHierarchy.greatestLowerBound(anno1, anno2);
+        AnnotationMirror glb = qualHierarchy.greatestLowerBoundShallow(anno1, tm1, anno2, tm2);
         lubLowerBound.replaceAnnotation(glb);
       }
     }
@@ -300,31 +331,34 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
     // For each hierarchy, if type1 is not a subtype of type2 and type2 is not a
     // subtype of type1, then the primary annotation on lub must be the effective upper
     // bound of type1 or type2, whichever is higher.
-    Set<AnnotationMirror> type1LowerBoundAnnos =
-        AnnotatedTypes.findEffectiveLowerBoundAnnotations(qualifierHierarchy, type1);
-    Set<AnnotationMirror> type2LowerBoundAnnos =
-        AnnotatedTypes.findEffectiveLowerBoundAnnotations(qualifierHierarchy, type2);
+    AnnotationMirrorSet type1LowerBoundAnnos =
+        AnnotatedTypes.findEffectiveLowerBoundAnnotations(qualHierarchy, type1);
+    AnnotationMirrorSet type2LowerBoundAnnos =
+        AnnotatedTypes.findEffectiveLowerBoundAnnotations(qualHierarchy, type2);
+
+    TypeMirror typeMirror1 = type1.getUnderlyingType();
+    TypeMirror typeMirror2 = type2.getUnderlyingType();
 
     for (AnnotationMirror lower1 : type1LowerBoundAnnos) {
-      AnnotationMirror top = qualifierHierarchy.getTopAnnotation(lower1);
+      AnnotationMirror top = qualHierarchy.getTopAnnotation(lower1);
 
       // Can't just call isSubtype because it will return false if bounds have
       // different annotations on component types
-      AnnotationMirror lower2 =
-          qualifierHierarchy.findAnnotationInHierarchy(type2LowerBoundAnnos, top);
+      AnnotationMirror lower2 = qualHierarchy.findAnnotationInHierarchy(type2LowerBoundAnnos, top);
       AnnotationMirror upper1 = type1.getEffectiveAnnotationInHierarchy(lower1);
       AnnotationMirror upper2 = type2.getEffectiveAnnotationInHierarchy(lower1);
 
-      if (qualifierHierarchy.isSubtype(upper2, upper1)
-          && qualifierHierarchy.isSubtype(upper1, upper2)
-          && qualifierHierarchy.isSubtype(lower1, lower2)
-          && qualifierHierarchy.isSubtype(lower2, lower1)) {
+      if (qualHierarchy.isSubtypeShallow(upper2, typeMirror2, upper1, typeMirror1)
+          && qualHierarchy.isSubtypeShallow(upper1, typeMirror1, upper2, typeMirror2)
+          && qualHierarchy.isSubtypeShallow(lower1, typeMirror1, lower2, typeMirror2)
+          && qualHierarchy.isSubtypeShallow(lower2, typeMirror2, lower1, typeMirror1)) {
         continue;
       }
 
-      if (!qualifierHierarchy.isSubtype(upper2, lower1)
-          && !qualifierHierarchy.isSubtype(upper1, lower2)) {
-        lub.replaceAnnotation(qualifierHierarchy.leastUpperBound(upper1, upper2));
+      if (!qualHierarchy.isSubtypeShallow(upper2, typeMirror2, lower1, typeMirror1)
+          && !qualHierarchy.isSubtypeShallow(upper1, typeMirror1, lower2, typeMirror2)) {
+        lub.replaceAnnotation(
+            qualHierarchy.leastUpperBoundShallow(upper1, typeMirror1, upper2, typeMirror2));
       }
     }
   }
@@ -357,12 +391,10 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
   }
 
   @Override
-  protected String defaultErrorMessage(
+  public String defaultErrorMessage(
       AnnotatedTypeMirror type1, AnnotatedTypeMirror type2, AnnotatedTypeMirror lub) {
-    return String.format(
-        "AtmLubVisitor: Unexpected combination: type1: %s type2: %s.%n"
-            + "type1: %s%ntype2: %s%nlub: %s",
-        type1.getKind(), type2.getKind(), type1, type2, lub);
+    return super.defaultErrorMessage(type1, type2, lub)
+        + String.format("%n  lub: %s %s", lub.getKind(), lub);
   }
 
   /**
@@ -377,7 +409,7 @@ class AtmLubVisitor extends AbstractAtmComboVisitor<Void, AnnotatedTypeMirror> {
     for (AnnotatedTypeMirror atmVisit : visited) {
       // Use reference equality rather than equals because the visitor may visit two types
       // that are structurally equal, but not actually the same.  For example, the
-      // wildcards in Pair<?,?> may be equal, but they both should be visited.
+      // wildcards in IPair<?,?> may be equal, but they both should be visited.
       if (atmVisit == atm) {
         return true;
       }
