@@ -14,6 +14,7 @@ import java.util.Set;
 import java.util.TreeMap;
 import java.util.TreeSet;
 import org.checkerframework.checker.initialization.qual.UnderInitialization;
+import org.checkerframework.checker.initialization.qual.UnknownInitialization;
 import org.checkerframework.checker.interning.qual.Interned;
 import org.checkerframework.checker.nullness.qual.KeyFor;
 import org.checkerframework.checker.nullness.qual.MonotonicNonNull;
@@ -111,8 +112,14 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
   }
 
   @Override
-  public @Nullable QualifierKind getQualifierKind(@CanonicalName String name) {
-    return nameToQualifierKind.get(name);
+  public QualifierKind getQualifierKind(
+      @UnknownInitialization(DefaultQualifierKindHierarchy.class) DefaultQualifierKindHierarchy this,
+      @CanonicalName String name) {
+    QualifierKind result = nameToQualifierKind.get(name);
+    if (result == null) {
+      throw new BugInCF("getQualifierKind(%s) => null", name);
+    }
+    return result;
   }
 
   /**
@@ -121,6 +128,7 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
    *
    * @param qualifierClasses all the classes of qualifiers supported by this hierarchy
    */
+  @SuppressWarnings("this-escape")
   public DefaultQualifierKindHierarchy(Collection<Class<? extends Annotation>> qualifierClasses) {
     this(qualifierClasses, null, null);
   }
@@ -137,6 +145,7 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
    * @param qualifierClasses all the classes of qualifiers supported by this hierarchy
    * @param bottom the bottom qualifier of this hierarchy
    */
+  @SuppressWarnings("this-escape")
   public DefaultQualifierKindHierarchy(
       Collection<Class<? extends Annotation>> qualifierClasses,
       Class<? extends Annotation> bottom) {
@@ -152,6 +161,7 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
    * @param voidParam void parameter to differentiate from {@link
    *     #DefaultQualifierKindHierarchy(Collection, Class)}
    */
+  @SuppressWarnings("this-escape")
   private DefaultQualifierKindHierarchy(
       Collection<Class<? extends Annotation>> qualifierClasses,
       @Nullable Class<? extends Annotation> bottom,
@@ -205,8 +215,8 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
         if (qualifierKind.top == null) {
           throw new TypeSystemError(
               "PolymorphicQualifier, %s, has to specify a type hierarchy in its"
-                  + " @PolymorphicQualifier meta-annotation, if more than one exists; top types:"
-                  + " [%s].",
+                  + " @PolymorphicQualifier meta-annotation, if more than one exists;"
+                  + " top types: [%s].",
               qualifierKind, StringsPlume.join(", ", tops));
         } else if (!tops.contains(qualifierKind.top)) {
           throw new TypeSystemError(
@@ -257,7 +267,7 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
    * method to create the direct super map some other way.
    *
    * <p>Note that this method is called from the constructor when {@link #nameToQualifierKind} and
-   * {@link #qualifierKinds} are the only fields that have nonnull values. This method is not
+   * {@link #qualifierKinds} are the only fields that have non-null values. This method is not
    * static, so it can be overridden by subclasses.
    *
    * @return a mapping from each {@link QualifierKind} to a set of its direct super qualifiers
@@ -279,7 +289,8 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
         DefaultQualifierKind superQualifier = nameToQualifierKind.get(superName);
         if (superQualifier == null) {
           throw new TypeSystemError(
-              "%s @Subtype argument %s isn't in the hierarchy. Qualifiers: [%s]",
+              "In %s, @SubtypeOf(%s) argument isn't in the hierarchy."
+                  + " Have you mis-defined createSupportedTypeQualifiers()? Qualifiers: [%s]",
               qualifierKind, superName, StringsPlume.join(", ", qualifierKinds));
         }
         directSupers.add(superQualifier);
@@ -499,7 +510,10 @@ public class DefaultQualifierKindHierarchy implements QualifierKindHierarchy {
 
       Set<DefaultQualifierKind> superSuperQuals = directSuperMap.get(superQualKind);
       if (superSuperQuals == null) {
-        throw new TypeSystemError(superQualKind + " is not a key in the directSuperMap");
+        throw new TypeSystemError(
+            superQualKind
+                + " is not a key in the directSuperMap."
+                + "  Does it have a @SubtypeOf annotation?");
       }
       toVisit.addAll(superSuperQuals);
       allSupers.addAll(superSuperQuals);
