@@ -28,11 +28,17 @@ import javax.annotation.processing.ProcessingEnvironment;
 import org.checkerframework.javacutil.BugInCF;
 
 /**
- * Utility methods for working with JavaParser. It is a replacement for StaticJavaParser that does
- * not leak memory, and it provides some other methods.
+ * Utility methods for working with JavaParser. It is a replacement for {@code
+ * com.github.javaparser.StaticJavaParser} that does not leak memory, and it provides some other
+ * methods.
  */
 public class JavaParserUtil {
 
+  /** Do not instantiate. */
+  private JavaParserUtil() {
+    throw new Error("Do not instantiate.");
+  }
+
   /**
    * The Language Level to use when parsing if a specific level isn't applied. This should be the
    * highest version of Java that the Checker Framework can process.
