@@ -37,6 +37,7 @@ import org.checkerframework.dataflow.cfg.node.Node;
 import org.checkerframework.dataflow.expression.FormalParameter;
 import org.checkerframework.dataflow.expression.JavaExpression;
 import org.checkerframework.dataflow.expression.JavaExpressionConverter;
+import org.checkerframework.dataflow.expression.JavaExpressionParseException;
 import org.checkerframework.dataflow.expression.LocalVariable;
 import org.checkerframework.dataflow.expression.SuperReference;
 import org.checkerframework.dataflow.expression.ThisReference;
@@ -52,7 +53,6 @@ import org.checkerframework.framework.type.treeannotator.TreeAnnotator;
 import org.checkerframework.framework.type.visitor.AnnotatedTypeScanner;
 import org.checkerframework.framework.type.visitor.DoubleAnnotatedTypeScanner;
 import org.checkerframework.framework.type.visitor.SimpleAnnotatedTypeScanner;
-import org.checkerframework.framework.util.JavaExpressionParseUtil.JavaExpressionParseException;
 import org.checkerframework.framework.util.StringToJavaExpression;
 import org.checkerframework.javacutil.AnnotationBuilder;
 import org.checkerframework.javacutil.AnnotationMirrorSet;
@@ -108,7 +108,7 @@ import org.plumelib.util.CollectionsPlume;
  */
 public class DependentTypesHelper {
 
-  /** AnnotatedTypeFactory */
+  /** AnnotatedTypeFactory. */
   protected final AnnotatedTypeFactory factory;
 
   /**
@@ -847,7 +847,7 @@ public class DependentTypesHelper {
   }
 
   /**
-   * Whether or not {@code expression} should be passed to the new annotation unchanged. If this
+   * Returns true if {@code expression} should be passed to the new annotation unchanged. If this
    * method returns true, the {@code expression} is not parsed.
    *
    * <p>The default implementation returns true if the {@code expression} is an expression error
@@ -855,8 +855,7 @@ public class DependentTypesHelper {
    * this method to add additional logic.
    *
    * @param expression an expression string in a dependent types annotation
-   * @return whether or not {@code expression} should be passed through unchanged to the new
-   *     annotation
+   * @return true if {@code expression} should be passed through unchanged to the new annotation
    */
   protected boolean shouldPassThroughExpression(String expression) {
     return DependentTypesError.isExpressionError(expression);
