@@ -8,13 +8,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** Tests the ClassVal Checker. */
 public class ClassValTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public ClassValTest(List<File> testFiles) {
-    super(
-        testFiles,
-        org.checkerframework.common.reflection.ClassValChecker.class,
-        "classval",
-        "-Anomsgtext");
+    super(testFiles, org.checkerframework.common.reflection.ClassValChecker.class, "classval");
   }
 
   @Parameters
