@@ -9,9 +9,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** Created by jburke on 9/29/14. */
 public class DefaultingUpperBoundTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public DefaultingUpperBoundTest(List<File> testFiles) {
-    super(testFiles, DefaultingUpperBoundChecker.class, "defaulting", "-Anomsgtext");
+    super(testFiles, DefaultingUpperBoundChecker.class, "defaulting");
   }
 
   @Parameters
