@@ -9,9 +9,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** */
 public class FlowTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public FlowTest(List<File> testFiles) {
-    super(testFiles, FlowTestChecker.class, "flow", "-Anomsgtext");
+    super(testFiles, FlowTestChecker.class, "flow", "-AcheckPurityAnnotations");
   }
 
   @Parameters
