@@ -9,14 +9,12 @@ import org.junit.runners.Parameterized.Parameters;
 /** */
 public class H1H2CheckerTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public H1H2CheckerTest(List<File> testFiles) {
     super(
-        testFiles,
-        H1H2Checker.class,
-        "h1h2checker",
-        "-Anomsgtext",
-        "-Astubs=tests/h1h2checker/h1h2checker.astub");
+        testFiles, H1H2Checker.class, "h1h2checker", "-Astubs=tests/h1h2checker/h1h2checker.astub");
   }
 
   @Parameters
