@@ -14,7 +14,7 @@ public class InitializedFieldsTest extends CheckerFrameworkPerDirectoryTest {
    * @param testFiles the files containing test code, which will be type-checked
    */
   public InitializedFieldsTest(List<File> testFiles) {
-    super(testFiles, InitializedFieldsChecker.class, "initialized-fields", "-Anomsgtext");
+    super(testFiles, InitializedFieldsChecker.class, "initialized-fields");
   }
 
   @Parameters
