@@ -8,13 +8,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** Tests the MethodVal Checker. */
 public class MethodValTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public MethodValTest(List<File> testFiles) {
-    super(
-        testFiles,
-        org.checkerframework.common.reflection.MethodValChecker.class,
-        "methodval",
-        "-Anomsgtext");
+    super(testFiles, org.checkerframework.common.reflection.MethodValChecker.class, "methodval");
   }
 
   @Parameters
