@@ -10,9 +10,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** Tests the reflection resolution using a simple type system. */
 public class ReflectionTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public ReflectionTest(List<File> testFiles) {
-    super(testFiles, ReflectionTestChecker.class, "reflection", "-Anomsgtext");
+    super(testFiles, ReflectionTestChecker.class, "reflection");
   }
 
   @Parameters
@@ -22,14 +24,14 @@ public class ReflectionTest extends CheckerFrameworkPerDirectoryTest {
 
   @Override
   public List<String> customizeOptions(List<String> previousOptions) {
-    final List<String> optionsWithStub = new ArrayList<>(checkerOptions);
+    List<String> optionsWithStub = new ArrayList<>(checkerOptions);
     optionsWithStub.add("-Astubs=" + getFullPath(testFiles.get(0), "reflection.astub"));
     optionsWithStub.add("-AresolveReflection");
     return optionsWithStub;
   }
 
-  protected String getFullPath(final File javaFile, final String filename) {
-    final String dirname = javaFile.getParentFile().getAbsolutePath();
+  protected String getFullPath(File javaFile, String filename) {
+    String dirname = javaFile.getParentFile().getAbsolutePath();
     return dirname + File.separator + filename;
   }
 }
