@@ -8,9 +8,11 @@ import org.junit.runners.Parameterized.Parameters;
 
 public class SupportedQualsTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public SupportedQualsTest(List<File> testFiles) {
-    super(testFiles, SupportedQualsChecker.class, "simple", "-Anomsgtext");
+    super(testFiles, SupportedQualsChecker.class, "simple");
   }
 
   @Parameters
