@@ -9,13 +9,14 @@ import org.junit.runners.Parameterized.Parameters;
 /** Create the TypeDeclDefault test. */
 public class TypeDeclDefaultTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public TypeDeclDefaultTest(List<File> testFiles) {
     super(
         testFiles,
         TypeDeclDefaultChecker.class,
         "typedecldefault",
-        "-Anomsgtext",
         "-Astubs=tests/typedecldefault/jdk.astub");
   }
 
