@@ -14,15 +14,15 @@ public class UnnamedPattern {
   public record WrappedBoolean(boolean b) implements IntOrBool {}
 
   public int test(IntOrBool i) {
-    int x = 0;
+    int x_up = 0;
     return switch (i) {
       case WrappedInt(_) -> {
-        x = x + 1;
-        yield x;
+        x_up = x_up + 1;
+        yield x_up;
       }
       case WrappedBoolean(_) -> {
-        x = x + 2;
-        yield x;
+        x_up = x_up + 2;
+        yield x_up;
       }
     };
   }
