@@ -10,6 +10,6 @@ public class Unparsable {
     // :: error: (expression.unparsable)
     @FlowExp("new Object()") Object o1 = null;
     // :: error: (expression.unparsable)
-    @FlowExp("int x = 0") Object o2 = null;
+    @FlowExp("int unparseable = 0") Object o2 = null;
   }
 }
