@@ -1,4 +1,4 @@
-import org.checkerframework.common.util.report.qual.*;
+import org.checkerframework.common.util.count.report.qual.*;
 
 public class Accesses {
   class Demo {
@@ -59,4 +59,10 @@ public class Accesses {
     // :: error: (methodcall)
     d.equals(d.foo(null));
   }
+
+  Object[] array = new Object[] {1, 2, 3};
+
+  void accessArray() {
+    array[0] = 1;
+  }
 }
